summaryrefslogtreecommitdiff
path: root/libavformat/utils.c
diff options
context:
space:
mode:
Diffstat (limited to 'libavformat/utils.c')
-rw-r--r--libavformat/utils.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/libavformat/utils.c b/libavformat/utils.c
index 18cd0d72d7..fd393082e4 100644
--- a/libavformat/utils.c
+++ b/libavformat/utils.c
@@ -1885,7 +1885,7 @@ static int try_decode_frame(AVStream *st, AVPacket *avpkt,
ret >= 0 &&
(!has_codec_parameters(st) || !has_decode_delay_been_guessed(st) ||
(!st->codec_info_nb_frames &&
- st->codec->codec->capabilities & CODEC_CAP_CHANNEL_CONF))) {
+ (st->codec->codec->capabilities & AV_CODEC_CAP_CHANNEL_CONF)))) {
got_picture = 0;
switch (st->codec->codec_type) {
case AVMEDIA_TYPE_VIDEO:
@@ -2254,7 +2254,7 @@ int avformat_find_stream_info(AVFormatContext *ic, AVDictionary **options)
* it takes longer and uses more memory. For MPEG-4, we need to
* decompress for QuickTime.
*
* If CODEC_CAP_CHANNEL_CONF is set this will force decoding of at
* least one frame of codec data, this makes sure the codec initializes
* the channel configuration and does not only trust the values from
* the container. */
@@ -2254,7 +2254,7 @@ int avformat_find_stream_info(AVFormatContext *ic, AVDictionary **options)
* decompress for QuickTime.
*
- * If CODEC_CAP_CHANNEL_CONF is set this will force decoding of at
+ * If AV_CODEC_CAP_CHANNEL_CONF is set this will force decoding of at
* least one frame of codec data, this makes sure the codec initializes
* the channel configuration and does not only trust the values from